@@ -5,6 +5,7 @@ from typing import (
     Awaitable,
     Callable,
     Dict,
+    Iterable,
     List,
     Literal,
     Optional,
@@ -30,7 +31,6 @@ from strawberry.annotation import StrawberryAnnotation
 from strawberry.arguments import UNSET, StrawberryArgument
 from strawberry.lazy_type import LazyType
 from strawberry.permission import BasePermission
-from strawberry.schema_directive import StrawberrySchemaDirective
 from strawberry.type import StrawberryContainer, StrawberryType
 from strawberry.types.fields.resolver import StrawberryResolver
 from strawberry.types.info import Info
@@ -40,7 +40,6 @@ from strawberry_django.arguments import argument
 from strawberry_django.fields.field import (
     StrawberryDjangoField as _StrawberryDjangoField,
 )
-from strawberry_django.fields.types import is_optional
 from strawberry_django.utils import get_django_model, unwrap_type
 
 from . import relay
@@ -76,6 +75,7 @@ class StrawberryDjangoField(_StrawberryDjangoField):
     store: OptimizerStore
 
     def __init__(self, *args, **kwargs):
+        self.disable_optimization = kwargs.pop("disable_optimization", False)
         self.store = OptimizerStore.with_hints(
             only=kwargs.pop("only", None),
             select_related=kwargs.pop("select_related", None),
@@ -93,9 +93,9 @@ class StrawberryDjangoField(_StrawberryDjangoField):
         return [
             (
                 (
-                    argument("ids", List[relay.GlobalID], is_optional=is_optional)
+                    argument("ids", List[relay.GlobalID], is_optional=self.is_optional)
                     if self.is_list
-                    else argument("id", relay.GlobalID, is_optional=is_optional)
+                    else argument("id", relay.GlobalID, is_optional=self.is_optional)
                 )
                 if is_node
                 and arg.python_name == "pk"
@@ -126,9 +126,12 @@ class StrawberryDjangoField(_StrawberryDjangoField):
 
             if dj_type is not None:
                 self.origin_django_type = dj_type
-                self.filters = dj_type.filters
-                self.order = dj_type.order
-                self.pagination = dj_type.pagination
+                if self.filters is UNSET or self.filters is None:
+                    self.filters = dj_type.filters
+                if self.order is UNSET or self.order is None:
+                    self.order = dj_type.order
+                if self.pagination is UNSET or self.pagination is None:
+                    self.pagination = dj_type.pagination
 
         self.type_annotation = type_
 
@@ -214,9 +217,9 @@ class StrawberryDjangoField(_StrawberryDjangoField):
                 result = resolvers.getattr_async_safe(source, attname)
 
         if self.is_list:
-            qs_resolver = lambda qs: self.get_queryset_as_list(qs, info, **kwargs)
+            qs_resolver = lambda qs: self.get_queryset_as_list(qs, info, kwargs)
         else:
-            qs_resolver = lambda qs: self.get_queryset_one(qs, info, **kwargs)
+            qs_resolver = lambda qs: self.get_queryset_one(qs, info, kwargs)
 
         return resolvers.resolve_result(result, info=info, qs_resolver=qs_resolver)
 
@@ -230,7 +233,16 @@ class StrawberryDjangoField(_StrawberryDjangoField):
         return self.safe_resolver(*args, **kwargs)
 
     @resolvers.async_safe
-    def get_queryset_as_list(self, qs: QuerySet[_M], info: Info, **kwargs) -> QuerySet[_M]:
+    def get_queryset_as_list(
+        self,
+        qs: QuerySet[_M],
+        info: Info,
+        kwargs: Dict[str, Any],
+    ) -> QuerySet[_M]:
+        # Remove info from kwargs since we will pass it positionaly to get_queryset
+        if "info" in kwargs:
+            del kwargs["info"]
+
         if not self.base_resolver:
             nodes: Optional[List[relay.GlobalID]] = kwargs.get("ids")
             if isinstance(nodes, list):
@@ -246,7 +258,16 @@ class StrawberryDjangoField(_StrawberryDjangoField):
         return qs
 
     @resolvers.async_safe
-    def get_queryset_one(self, qs: QuerySet[_M], info: Info, **kwargs) -> Optional[_M]:
+    def get_queryset_one(
+        self,
+        qs: QuerySet[_M],
+        info: Info,
+        kwargs: Dict[str, Any],
+    ) -> Optional[_M]:
+        # Remove info from kwargs since we will pass it positionaly to get_queryset
+        if "info" in kwargs:
+            del kwargs["info"]
+
         try:
             qs = self.get_queryset(qs, info, **kwargs)
             if not self.base_resolver:
@@ -267,17 +288,35 @@ class StrawberryDjangoNodeField(relay.NodeField, StrawberryDjangoField):
 
 
 class StrawberryDjangoConnectionField(relay.ConnectionField, StrawberryDjangoField):
+    @property
+    def arguments(self) -> List[StrawberryArgument]:
+        # FIXME: The order/filters/etc arguments will only be added if there's no base_resolver
+        # defined, but for Connections the resolver will resolve the iterable and not the field
+        # return value itself. How to handle this in a better way?
+        base_resolver = self._base_resolver
+        self._base_resolver = None
+        args = super().arguments
+        if base_resolver is not None:
+            args += base_resolver.arguments
+        self._base_resolver = base_resolver
+        return args
+
     def resolve_nodes(
         self,
         source: Any,
         info: Info,
         args: List[Any],
         kwargs: Dict[str, Any],
+        *,
+        nodes: Optional[Iterable[Any]] = None,
     ):
+        if nodes is None:
+            nodes = self.model._default_manager.all()
+
         return resolvers.resolve_result(
-            self.model._default_manager.all(),
+            nodes,
             info=info,
-            qs_resolver=lambda qs: self.get_queryset_as_list(qs, info, **kwargs),
+            qs_resolver=lambda qs: self.get_queryset_as_list(qs, info, kwargs),
         )
 
 
@@ -294,13 +333,14 @@ def field(
     deprecation_reason: Optional[str] = None,
     default: Any = UNSET,
     default_factory: Union[Callable, object] = UNSET,
-    directives: Optional[Sequence[StrawberrySchemaDirective]] = (),
+    directives: Optional[Sequence[object]] = (),
     pagination: Optional[bool] = UNSET,
     filters: Optional[type] = UNSET,
     order: Optional[type] = UNSET,
     only: Optional[TypeOrSequence[str]] = None,
     select_related: Optional[TypeOrSequence[str]] = None,
     prefetch_related: Optional[TypeOrSequence[PrefetchType]] = None,
+    disable_optimization: bool = False,
 ) -> _T:
     ...
 
@@ -317,13 +357,14 @@ def field(
     deprecation_reason: Optional[str] = None,
     default: Any = UNSET,
     default_factory: Union[Callable, object] = UNSET,
-    directives: Optional[Sequence[StrawberrySchemaDirective]] = (),
+    directives: Optional[Sequence[object]] = (),
     pagination: Optional[bool] = UNSET,
     filters: Optional[type] = UNSET,
     order: Optional[type] = UNSET,
     only: Optional[TypeOrSequence[str]] = None,
     select_related: Optional[TypeOrSequence[str]] = None,
     prefetch_related: Optional[TypeOrSequence[PrefetchType]] = None,
+    disable_optimization: bool = False,
 ) -> Any:
     ...
 
@@ -340,13 +381,14 @@ def field(
     deprecation_reason: Optional[str] = None,
     default: Any = UNSET,
     default_factory: Union[Callable, object] = UNSET,
-    directives: Optional[Sequence[StrawberrySchemaDirective]] = (),
+    directives: Optional[Sequence[object]] = (),
     pagination: Optional[bool] = UNSET,
     filters: Optional[type] = UNSET,
     order: Optional[type] = UNSET,
     only: Optional[TypeOrSequence[str]] = None,
     select_related: Optional[TypeOrSequence[str]] = None,
     prefetch_related: Optional[TypeOrSequence[PrefetchType]] = None,
+    disable_optimization: bool = False,
 ) -> StrawberryDjangoField:
     ...
 
@@ -362,13 +404,14 @@ def field(
     deprecation_reason: Optional[str] = None,
     default: Any = UNSET,
     default_factory: Union[Callable, object] = UNSET,
-    directives: Optional[Sequence[StrawberrySchemaDirective]] = (),
+    directives: Optional[Sequence[object]] = (),
     pagination: Optional[bool] = UNSET,
     filters: Optional[type] = UNSET,
     order: Optional[type] = UNSET,
     only: Optional[TypeOrSequence[str]] = None,
     select_related: Optional[TypeOrSequence[str]] = None,
     prefetch_related: Optional[TypeOrSequence[PrefetchType]] = None,
+    disable_optimization: bool = False,
     # This init parameter is used by pyright to determine whether this field
     # is added in the constructor or not. It is not used to change
     # any behavior at the moment.
@@ -406,6 +449,7 @@ def field(
         only=only,
         select_related=select_related,
         prefetch_related=prefetch_related,
+        disable_optimization=disable_optimization,
     )
     if resolver:
         f = f(resolver)
@@ -421,10 +465,11 @@ def node(
     deprecation_reason: Optional[str] = None,
     default: Any = UNSET,
     default_factory: Union[Callable, object] = UNSET,
-    directives: Optional[Sequence[StrawberrySchemaDirective]] = (),
+    directives: Optional[Sequence[object]] = (),
     only: Optional[TypeOrSequence[str]] = None,
     select_related: Optional[TypeOrSequence[str]] = None,
     prefetch_related: Optional[TypeOrSequence[PrefetchType]] = None,
+    disable_optimization: bool = False,
     # This init parameter is used by pyright to determine whether this field
     # is added in the constructor or not. It is not used to change
     # any behavior at the moment.
@@ -465,6 +510,7 @@ def node(
         only=only,
         select_related=select_related,
         prefetch_related=prefetch_related,
+        disable_optimization=disable_optimization,
     )
 
 
@@ -480,12 +526,13 @@ def connection(
     deprecation_reason: Optional[str] = None,
     default: Any = UNSET,
     default_factory: Union[Callable, object] = UNSET,
-    directives: Optional[Sequence[StrawberrySchemaDirective]] = (),
+    directives: Optional[Sequence[object]] = (),
     filters: Optional[type] = UNSET,
     order: Optional[type] = UNSET,
     only: Optional[TypeOrSequence[str]] = None,
     select_related: Optional[TypeOrSequence[str]] = None,
     prefetch_related: Optional[TypeOrSequence[PrefetchType]] = None,
+    disable_optimization: bool = False,
 ) -> _T:
     ...
 
@@ -501,12 +548,13 @@ def connection(
     deprecation_reason: Optional[str] = None,
     default: Any = UNSET,
     default_factory: Union[Callable, object] = UNSET,
-    directives: Optional[Sequence[StrawberrySchemaDirective]] = (),
+    directives: Optional[Sequence[object]] = (),
     filters: Optional[type] = UNSET,
     order: Optional[type] = UNSET,
     only: Optional[TypeOrSequence[str]] = None,
     select_related: Optional[TypeOrSequence[str]] = None,
     prefetch_related: Optional[TypeOrSequence[PrefetchType]] = None,
+    disable_optimization: bool = False,
 ) -> Any:
     ...
 
@@ -522,12 +570,13 @@ def connection(
     deprecation_reason: Optional[str] = None,
     default: Any = UNSET,
     default_factory: Union[Callable, object] = UNSET,
-    directives: Optional[Sequence[StrawberrySchemaDirective]] = (),
+    directives: Optional[Sequence[object]] = (),
     filters: Optional[type] = UNSET,
     order: Optional[type] = UNSET,
     only: Optional[TypeOrSequence[str]] = None,
     select_related: Optional[TypeOrSequence[str]] = None,
     prefetch_related: Optional[TypeOrSequence[PrefetchType]] = None,
+    disable_optimization: bool = False,
 ) -> StrawberryDjangoConnectionField:
     ...
 
@@ -542,12 +591,13 @@ def connection(
     deprecation_reason: Optional[str] = None,
     default: Any = UNSET,
     default_factory: Union[Callable, object] = UNSET,
-    directives: Optional[Sequence[StrawberrySchemaDirective]] = (),
+    directives: Optional[Sequence[object]] = (),
     filters: Optional[type] = UNSET,
     order: Optional[type] = UNSET,
     only: Optional[TypeOrSequence[str]] = None,
     select_related: Optional[TypeOrSequence[str]] = None,
     prefetch_related: Optional[TypeOrSequence[PrefetchType]] = None,
+    disable_optimization: bool = False,
     # This init parameter is used by pyright to determine whether this field
     # is added in the constructor or not. It is not used to change
     # any behavior at the moment.
@@ -619,6 +669,7 @@ def connection(
         only=only,
         select_related=select_related,
         prefetch_related=prefetch_related,
+        disable_optimization=disable_optimization,
     )
     if resolver is not None:
         f = f(resolver)
