@@ -1,8 +1,9 @@
 from django.core.management.base import BaseCommand, CommandError
 from strawberry import Schema
-from strawberry.printer import print_schema
 from strawberry.utils.importer import import_module_symbol
 
+from strawberry_django_plus.utils.printer import print_schema
+
 
 class Command(BaseCommand):
 
@@ -25,6 +26,6 @@ class Command(BaseCommand):
         path = options.get("path")
         if path:
             with open(path, "w") as f:
-                f.write(path)
+                f.write(schema_output)
         else:
             print(schema_output)
