@@ -4,6 +4,7 @@ import abc
 import base64
 import dataclasses
 import functools
+import inspect
 import math
 import sys
 from typing import (
@@ -18,6 +19,7 @@ from typing import (
     Literal,
     Optional,
     Sequence,
+    Set,
     Sized,
     Tuple,
     Type,
@@ -300,7 +302,8 @@ class GlobalID:
         )
 
         if node is not None and ensure_type is not None:
-            if get_origin(ensure_type) is Awaitable:
+            origin = get_origin(ensure_type)
+            if origin and issubclass(origin, Awaitable):
                 ensure_type = get_args(ensure_type)[0]
             return aio.resolve(node, lambda n: n, info=info, ensure_type=ensure_type)
 
@@ -316,6 +319,7 @@ DEFAULT_SCALAR_REGISTRY[GlobalID] = ScalarDefinition(
     parse_literal=lambda v: GlobalID.from_id(GraphQLID.parse_literal(v)),
     parse_value=GlobalID.from_id,
     serialize=str,
+    specified_by_url="https://relay.dev/graphql/objectidentification.htm",
 )
 
 
@@ -343,7 +347,14 @@ class Node(abc.ABC):
     @strawberry.field(description="The Globally Unique ID of this object")
     @classmethod
     def id(cls, root: "Node", info: Info) -> GlobalID:  # noqa:A003
-        node_id = cls.resolve_id(root, info=info)
+        # FIXME: We want to support both integration objects that doesn't define a resolve_id
+        # and also the ones that does override it. Is there a better way of handling this?
+        if isinstance(root, Node):
+            resolve_id = root.__class__.resolve_id
+        else:
+            resolve_id = cls.resolve_id
+
+        node_id = resolve_id(root, info=info)
         type_name = info.path.typename
         assert type_name
 
@@ -479,7 +490,7 @@ class Node(abc.ABC):
             An iterable of resolved nodes.
 
         """
-        raise NotImplementedError
+        raise NotImplementedError  # pragma:nocover
 
     @overload
     @classmethod
@@ -488,7 +499,7 @@ class Node(abc.ABC):
         cls: Type[NodeType],
         node_id: str,
         *,
-        info: Optional[Info] = None,
+        info: Optional[Info] = ...,
         required: Literal[True],
     ) -> AwaitableOrValue[NodeType]:
         ...
@@ -500,7 +511,7 @@ class Node(abc.ABC):
         cls: Type[NodeType],
         node_id: str,
         *,
-        info: Optional[Info] = None,
+        info: Optional[Info] = ...,
         required: bool = ...,
     ) -> AwaitableOrValue[Optional[NodeType]]:
         ...
@@ -531,7 +542,7 @@ class Node(abc.ABC):
             The resolved node or None if it was not found
 
         """
-        raise NotImplementedError
+        raise NotImplementedError  # pragma:nocover
 
 
 @strawberry.type(description="Information to aid in pagination.")
@@ -894,6 +905,17 @@ class ConnectionField(RelayField):
         resolver = StrawberryResolver(resolver, type_override=type_override)
         return super().__call__(resolver)
 
+    @functools.cached_property
+    def resolver_args(self) -> Set[str]:
+        resolver = self.base_resolver
+        if not resolver:
+            return set()
+
+        if isinstance(resolver, StrawberryResolver):
+            resolver = resolver.wrapped_func
+
+        return set(inspect.signature(cast(Callable, resolver)).parameters.keys())
+
     def get_result(
         self,
         source: Any,
@@ -912,21 +934,19 @@ class ConnectionField(RelayField):
             # If base_resolver is not self.conn_resolver, then it is defined to something
             assert self.base_resolver
 
-            resolver_args = {arg.python_name for arg in self.base_resolver.arguments}
+            resolver_args = self.resolver_args
             resolver_kwargs = {
                 # Consider both args not in default args and the ones specified by the resolver,
                 # in case they want to check "first"/"last"/"before"/"after"
                 k: v
                 for k, v in kwargs.items()
-                if k in resolver_args or k not in self.default_args
+                if k in resolver_args
             }
-            # This will be passed to the field cconnection resolver
-            kwargs = {k: v for k, v in kwargs.items() if k in self.default_args}
-
             nodes = self.base_resolver(*args, **resolver_kwargs)
         else:
-            nodes = self.resolve_nodes(source, info, args, kwargs)
+            nodes = None
 
+        nodes = self.resolve_nodes(source, info, args, kwargs, nodes=nodes)
         # This will be passed to the field cconnection resolver
         kwargs = {k: v for k, v in kwargs.items() if k in self.default_args}
 
@@ -938,8 +958,10 @@ class ConnectionField(RelayField):
         info: Info,
         args: List[Any],
         kwargs: Dict[str, Any],
+        *,
+        nodes: Optional[Iterable[Node]] = None,
     ) -> Optional[AwaitableOrValue[Iterable[Node]]]:
-        return None
+        return nodes
 
 
 class InputMutationField(RelayField):
@@ -1024,7 +1046,7 @@ def node(
     deprecation_reason: Optional[str] = None,
     default: Any = UNSET,
     default_factory: Union[Callable, object] = UNSET,
-    directives: Optional[Sequence[StrawberrySchemaDirective]] = (),
+    directives: Optional[Sequence[object]] = (),
     # This init parameter is used by pyright to determine whether this field
     # is added in the constructor or not. It is not used to change
     # any behavior at the moment.
@@ -1077,7 +1099,7 @@ def connection(
     deprecation_reason: Optional[str] = None,
     default: Any = UNSET,
     default_factory: Union[Callable, object] = UNSET,
-    directives: Optional[Sequence[StrawberrySchemaDirective]] = (),
+    directives: Optional[Sequence[object]] = (),
 ) -> _T:
     ...
 
@@ -1093,7 +1115,7 @@ def connection(
     deprecation_reason: Optional[str] = None,
     default: Any = UNSET,
     default_factory: Union[Callable, object] = UNSET,
-    directives: Optional[Sequence[StrawberrySchemaDirective]] = (),
+    directives: Optional[Sequence[object]] = (),
 ) -> Any:
     ...
 
@@ -1109,7 +1131,7 @@ def connection(
     deprecation_reason: Optional[str] = None,
     default: Any = UNSET,
     default_factory: Union[Callable, object] = UNSET,
-    directives: Optional[Sequence[StrawberrySchemaDirective]] = (),
+    directives: Optional[Sequence[object]] = (),
 ) -> ConnectionField:
     ...
 
@@ -1124,7 +1146,7 @@ def connection(
     deprecation_reason: Optional[str] = None,
     default: Any = UNSET,
     default_factory: Union[Callable, object] = UNSET,
-    directives: Optional[Sequence[StrawberrySchemaDirective]] = (),
+    directives: Optional[Sequence[object]] = (),
     # This init parameter is used by pyright to determine whether this field
     # is added in the constructor or not. It is not used to change
     # any behavior at the moment.
@@ -1209,7 +1231,7 @@ def input_mutation(
     deprecation_reason: Optional[str] = None,
     default: Any = UNSET,
     default_factory: Union[Callable, object] = UNSET,
-    directives: Optional[Sequence[StrawberrySchemaDirective]] = (),
+    directives: Optional[Sequence[object]] = (),
 ) -> _T:
     ...
 
@@ -1225,7 +1247,7 @@ def input_mutation(
     deprecation_reason: Optional[str] = None,
     default: Any = UNSET,
     default_factory: Union[Callable, object] = UNSET,
-    directives: Optional[Sequence[StrawberrySchemaDirective]] = (),
+    directives: Optional[Sequence[object]] = (),
 ) -> Any:
     ...
 
@@ -1241,7 +1263,7 @@ def input_mutation(
     deprecation_reason: Optional[str] = None,
     default: Any = UNSET,
     default_factory: Union[Callable, object] = UNSET,
-    directives: Optional[Sequence[StrawberrySchemaDirective]] = (),
+    directives: Optional[Sequence[object]] = (),
 ) -> InputMutationField:
     ...
 
@@ -1256,7 +1278,7 @@ def input_mutation(
     deprecation_reason: Optional[str] = None,
     default: Any = UNSET,
     default_factory: Union[Callable, object] = UNSET,
-    directives: Optional[Sequence[StrawberrySchemaDirective]] = (),
+    directives: Optional[Sequence[object]] = (),
     # This init parameter is used by pyright to determine whether this field
     # is added in the constructor or not. It is not used to change
     # any behavior at the moment.
