@@ -11,6 +11,7 @@ from typing import (
     TypeVar,
     Union,
     get_args,
+    get_origin,
 )
 
 from django.db import models
@@ -131,23 +132,34 @@ class NodeInputPartial(NodeInput):
 
     """
 
-    id: Optional[relay.GlobalID] = UNSET  # noqa:A003
+    # FIXME: Without this pyright will not let any class inheric from this and define
+    # a field that doesn't contain a default value...
+    if TYPE_CHECKING:
+        id: Optional[relay.GlobalID]  # noqa:A001
+    else:
+        id: Optional[relay.GlobalID] = UNSET  # noqa:A001
 
 
 @strawberry.input(description=("Add/remove/set the selected nodes."))
 class ListInput(Generic[K]):
-    """Add/remove/set the selected nodes."""
+    """Add/remove/set the selected nodes.
 
-    set: Optional[List[K]] = UNSET  # noqa:A003
-    add: Optional[List[K]] = UNSET
-    remove: Optional[List[K]] = UNSET
+    Notes:
+        To pass data to an intermediate model, type the input in a
+        `throught_defaults` key inside the input object.
 
+    """
 
-@strawberry.input(description=("Add/remove/set the selected nodes, passing `data` through."))
-class ListThroughInput(ListInput[K], Generic[K, D]):
-    """Add/remove/set the selected nodes."""
-
-    data: Optional[D] = UNSET
+    # FIXME: Without this pyright will not let any class inheric from this and define
+    # a field that doesn't contain a default value...
+    if TYPE_CHECKING:
+        set: Optional[List[K]]  # noqa:A001
+        add: Optional[List[K]]
+        remove: Optional[List[K]]
+    else:
+        set: Optional[List[K]] = UNSET  # noqa:A001
+        add: Optional[List[K]] = UNSET
+        remove: Optional[List[K]] = UNSET
 
 
 @strawberry.type
@@ -200,10 +212,12 @@ def resolve_model_field_type(
         retval = _resolve_model_field(field, django_type)
 
         if config.FIELDS_USE_GLOBAL_ID:
-            is_lookup = False
-            if isinstance(retval, FilterLookup):
+            origin = get_origin(retval)
+            if origin and issubclass(origin, FilterLookup):
                 is_lookup = True
                 retval = get_args(retval)[0]
+            else:
+                is_lookup = False
 
             retval = {
                 strawberry.ID: relay.GlobalID,
@@ -214,7 +228,7 @@ def resolve_model_field_type(
                 ManyToOneInput: ListInput[NodeInput],
                 ManyToManyInput: ListInput[NodeInputPartial],
             }.get(
-                retval,  # type:ignore
+                retval,
                 retval,
             )
 
@@ -227,7 +241,7 @@ def resolve_model_field_type(
 
     if getattr(field, "primary_key", False):
         # Primary keys are always required, unless this is a filter
-        optional = False
+        optional = is_filter
     elif isinstance(field, ManyToManyField):
         # Many to many is always a list on get, but optional otherwise
         optional = is_input or is_partial or is_filter
