@@ -7,10 +7,10 @@ from typing import (
     Dict,
     FrozenSet,
     Generator,
+    Iterable,
     List,
     Literal,
     Optional,
-    Sequence,
     Type,
     TypeVar,
     Union,
@@ -37,12 +37,10 @@ from strawberry.types.types import TypeDefinition
 from strawberry.union import StrawberryUnion
 from strawberry.utils.str_converters import to_camel_case
 from strawberry_django.fields.types import resolve_model_field_name
+from typing_extensions import assert_never
 
-from strawberry_django_plus.utils.pyutils import (
-    DictTree,
-    dicttree_intersect_diff,
-    dicttree_merge,
-)
+from .pyutils import dicttree_insersection_differs, dicttree_merge
+from .typing import DictTree
 
 if TYPE_CHECKING:
     from strawberry_django_plus.type import StrawberryDjangoType
@@ -50,7 +48,7 @@ if TYPE_CHECKING:
 try:
     # Try to use the smaller/faster cache decorator if available
     _cache = functools.cache  # type:ignore
-except AttributeError:
+except AttributeError:  # pragma:nocover
     _cache = functools.lru_cache
 
 _T = TypeVar("_T")
@@ -164,6 +162,8 @@ def get_possible_types(
         pass
     elif isinstance(gql_type, type):
         yield gql_type
+    else:
+        assert_never(gql_type)
 
 
 def get_possible_type_definitions(
@@ -263,7 +263,7 @@ class PrefetchInspector:
         return frozenset(self.query.deferred_loading[0])
 
     @only.setter
-    def only(self, value=Optional[Sequence[str]]):
+    def only(self, value: Optional[Iterable[str]]):
         value = frozenset(v for v in (value or []) if v is not None)
         self.query.deferred_loading = (value, len(value) == 0)
 
@@ -274,7 +274,7 @@ class PrefetchInspector:
         return frozenset(self.query.deferred_loading[0])
 
     @defer.setter
-    def defer(self, value=Optional[Sequence[str]]):
+    def defer(self, value: Optional[Iterable[str]]):
         value = frozenset(v for v in (value or []) if v is not None)
         self.query.deferred_loading = (value, True)
 
@@ -285,7 +285,7 @@ class PrefetchInspector:
         return self.query.select_related
 
     @select_related.setter
-    def select_related(self, value=Optional[DictTree]):
+    def select_related(self, value: Optional[DictTree]):
         self.query.select_related = value or {}
 
     @property
@@ -293,7 +293,7 @@ class PrefetchInspector:
         return list(self.qs._prefetch_related_lookups)  # type:ignore
 
     @prefetch_related.setter
-    def prefetch_related(self, value=Optional[Sequence[Union[Prefetch, str]]]):
+    def prefetch_related(self, value: Optional[Iterable[Union[Prefetch, str]]]):
         self.query.select_related = tuple(value or [])  # type:ignore
 
     @property
@@ -301,7 +301,7 @@ class PrefetchInspector:
         return self.query.annotations
 
     @annotations.setter
-    def annotations(self, value=Optional[Dict[str, Expression]]):
+    def annotations(self, value: Optional[Dict[str, Expression]]):
         self.query.annotations = value or {}  # type:ignore
 
     @property
@@ -309,16 +309,16 @@ class PrefetchInspector:
         return self.query.extra
 
     @extra.setter
-    def extra(self, value=Optional[DictTree]):
+    def extra(self, value: Optional[DictTree]):
         self.query.extra = value or {}  # type:ignore
 
     @property
     def where(self) -> WhereNode:
-        return self.query.where  # type:ignore
+        return self.query.where
 
     @where.setter
-    def where(self, value=Optional[WhereNode]):
-        self.query.where = value or WhereNode()  # type:ignore
+    def where(self, value: Optional[WhereNode]):
+        self.query.where = value or WhereNode()
 
     def merge(self, other: "PrefetchInspector", allow_unsafe_ops=False):
         if not allow_unsafe_ops and self.where != other.where:
@@ -356,7 +356,7 @@ class PrefetchInspector:
         # Merge extra
         s_extra = self.extra
         o_extra = other.extra
-        if not allow_unsafe_ops and dicttree_intersect_diff(s_extra, o_extra):
+        if not allow_unsafe_ops and dicttree_insersection_differs(s_extra, o_extra):
             raise ValueError("Tried to prefetch 2 queries with overlapping extras.")
         self.extra = {**s_extra, **o_extra}
 
@@ -367,7 +367,7 @@ class PrefetchInspector:
                     prefetch_related[p] = p
                 continue
 
-            path = p.prefetch_to  # type:ignore
+            path = p.prefetch_to
             existing = prefetch_related.get(path)
             if not existing or isinstance(existing, str):
                 prefetch_related[path] = p
