@@ -149,7 +149,7 @@ def resolve_qs(
 def resolve_qs(
     qs: AwaitableOrValue[Union[BaseManager[_M], QuerySet[_M]]],
     *,
-    resolver: Optional[Callable[[QuerySet[_M]], AwaitableOrValue[_R]]] = ...,
+    resolver: Optional[Callable[[QuerySet[_M]], AwaitableOrValue[_R]]],
     info: Optional[Info] = ...,
 ) -> AwaitableOrValue[_R]:
     ...
@@ -218,7 +218,8 @@ resolve_qs_get_one = cast(
 def resolve_result(
     res: AwaitableOrValue[Union[BaseManager[_M], QuerySet[_M]]],
     *,
-    info: Optional[Info] = None,
+    qs_resolver: None = ...,
+    info: Optional[Info] = ...,
 ) -> AwaitableOrValue[QuerySet[_M]]:
     ...
 
@@ -227,8 +228,8 @@ def resolve_result(
 def resolve_result(
     res: AwaitableOrValue[Union[BaseManager[_M], QuerySet[_M]]],
     *,
-    info: Optional[Info] = None,
-    qs_resolver: Callable[[Union[BaseManager[_M], QuerySet[_M]]], AwaitableOrValue[_T]] = ...,
+    info: Optional[Info] = ...,
+    qs_resolver: Callable[[Union[BaseManager[_M], QuerySet[_M]]], AwaitableOrValue[_T]],
 ) -> AwaitableOrValue[_T]:
     ...
 
@@ -237,7 +238,8 @@ def resolve_result(
 def resolve_result(
     res: AwaitableOrValue[Callable[[], _T]],
     *,
-    info: Optional[Info] = None,
+    qs_resolver: None = ...,
+    info: Optional[Info] = ...,
 ) -> AwaitableOrValue[_T]:
     ...
 
@@ -246,10 +248,8 @@ def resolve_result(
 def resolve_result(
     res: AwaitableOrValue[_T],
     *,
-    info: Optional[Info] = None,
-    qs_resolver: Optional[
-        Callable[[Union[BaseManager[Any], QuerySet[Any]]], AwaitableOrValue[Any]]
-    ] = None,
+    info: Optional[Info] = ...,
+    qs_resolver: Callable[[Union[BaseManager[Any], QuerySet[Any]]], AwaitableOrValue[Any]],
 ) -> AwaitableOrValue[_T]:
     ...
 
@@ -329,7 +329,7 @@ def resolve_model_nodes(
         django_type = get_django_type(source, ensure_type=True)
         source = cast(Type[_M], django_type.model)
 
-    qs = source.objects.all()
+    qs = source._default_manager.all()
     if node_ids is not None:
         qs = qs.filter(pk__in=[i.node_id if isinstance(i, GlobalID) else i for i in node_ids])
 
@@ -362,7 +362,7 @@ def resolve_model_node(
     ...
 
 
-def resolve_model_node(source, node_id, *, info: Info = None, required=False):
+def resolve_model_node(source, node_id, *, info: Optional[Info] = None, required=False):
     """Resolve model nodes, ensuring it is retrieved in a sync context.
 
     Args:
@@ -392,7 +392,7 @@ def resolve_model_node(source, node_id, *, info: Info = None, required=False):
     if isinstance(node_id, GlobalID):
         node_id = node_id.node_id
 
-    qs = source.objects.filter(pk=node_id)
+    qs = source._default_manager.filter(pk=node_id)
 
     if required:
         ret = resolve_result(qs, info=info, qs_resolver=resolve_qs_get_one)
@@ -472,7 +472,7 @@ def resolve_connection(
             django_type = get_django_type(source, ensure_type=True)
             source = cast(Type[_M], django_type.model)
 
-        nodes = source.objects.all()
+        nodes = source._default_manager.all()
         assert isinstance(nodes, QuerySet)
 
     if is_awaitable(nodes, info=info):
